///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
////////////////////                                  /////////////////////////
////////////////////     NOKIA FBUS CONTROL V1.71     /////////////////////////
////////////////////                                  /////////////////////////
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
//////////////////////                               //////////////////////////
////////////////////// COPYRIGHT MARTIN FORSTER 2006 //////////////////////////
//////////////////////                               //////////////////////////
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////

#include<16F876.h> // Standard header for PIC16F876
#include<stdlib.h> // Standard header for std input/output
#include<string.h> // Standard header for string handling

#fuses HS, NOWDT, NOPROTECT, NOBROWNOUT, NOLVP, PUT

#use fast_io(A)
#use fast_io(B)
#use fast_io(C)

#use delay(clock=11059200)

#include </include/defines.h>
#include </include/prototypes.c>
#include </include/variables.c>
#include </include/structs.c>
#include </include/dog_lcd.c>
#include </include/fbus_control.c>
#include </include/2416.c>
#include </include/phone.c>
#include </include/sms.c>

///////////////////////////////////////////////////////////////////////////////
////////////////////////////// MAIN FUNCTION //////////////////////////////////
///////////////////////////////////////////////////////////////////////////////

#SEPARATE VOID main(){

setup_adc_ports(NO_ANALOGS); // Make PORT A digital

set_tris_a(0x31); // A0, A4 & A5 are inputs, A1, A2 & A3 are outputs
set_tris_b(0x01); // Only PIN B0 is input (Interrupt input)
set_tris_c(0x80); // Only PIN C7 is input (USART RX input)

output_b(0x09); // Only PIN B0 & B3 are high

ext_int_edge(H_TO_L);
enable_interrupts(INT_EXT);
enable_interrupts(GLOBAL);

b.INTERRUPT = 1;
b.SYS_READY_BUSY = 0;

lcd_init();
gotoxy(1, 1);

init_ext_eeprom();

#ifdef BRD_CHECK
board_check();
#endif

usart_sync();
usart_clear();

if(hwsw()){          lcd_putchar("Get-HWSW ok.    ");
                     success();
                     blanking();}
else{                lcd_putchar("Get-HWSW failed!");
                     error();
                     blanking();
                     reset_cpu();}

gotoxy(1, 1);

if(get_smsc()){      lcd_putchar("SMSC number:");
                     gotoxy(1, 2);
                     for(i=0; i<6; i++){
                     printf(lcd_putchar, "%i", (SMS_NUMBERS[i] & 0xF));
                     printf(lcd_putchar, "%i", (SMS_NUMBERS[i] >> 4));}
                     success();
                     blanking();}
else{                lcd_putchar("Get-SMSC failed!");
                     error();
                     blanking();
                     reset_cpu();}

gotoxy(1, 1);

if(sms_delete()){    lcd_putchar("Old SMS deleted.");
                     success();
                     blanking();}
else{                lcd_putchar("SMS delete      ");
                     gotoxy(1, 2);
                     lcd_putchar("failed!         ");
                     error();
                     blanking();
                     reset_cpu();}

phone_type_output();
blanking();

hwsw_output();
blanking();

if(sms_rx()){        gotoxy(1, 1);
                     lcd_putchar("Successfully    ");
                     gotoxy(1, 2);
                     lcd_putchar("received SMS.   ");
                     rxtx_success();
                     gotoxy(1, 3);
                     printf(lcd_putchar, "TXInfoFlag=%X   ", TX_INFO_FLAG);
                     blanking();}

else{                gotoxy(1, 1);
                     lcd_putchar("ERROR:Wrong     ");
                     gotoxy(1, 2);
                     lcd_putchar("frame received! ");
                     rxtx_error();
                     gotoxy(1, 3);
                     printf(lcd_putchar, "TXInfoFlag=%X   ", TX_INFO_FLAG);
                     blanking();
                     reset_cpu();}

if(sms_tx()){        lcd_putchar("Successfully    ");
                     gotoxy(1, 2);
                     lcd_putchar("sent SMS.       ");
                     rxtx_success();
                     blanking();}

else{                blanking();
                     gotoxy(1, 1);
                     lcd_putchar("Message sending ");
                     gotoxy(1, 2);
                     lcd_putchar("failed!         ");
                     rxtx_error();
                     blanking();
                     reset_cpu();}

delay_ms(100);
reset_cpu(); // Resetting to begin again
b.SYS_READY_BUSY = 1;} // Not busy anymore
